from setuptools import setup

setup(name="mexm",
      version="0.1.0",
      description="Materials Ex Machina",
      url="https://github.com/eragasa/mexm-base",
      author="Eugene J. Ragasa",
      author_email="eragasa@osc.edu",
      license="MIT License",
      packages=["mexm",],
      zip_safe=True)
